==> chaosmesh-model-5.1.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosStatusBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodNetworkChaosStatusBuilder extends PodNetworkChaosStatusFluentImpl<PodNetworkChaosStatusBuilder> implements VisitableBuilder<PodNetworkChaosStatus,PodNetworkChaosStatusBuilder> {

    PodNetworkChaosStatusFluent<?> fluent;
    Boolean validationEnabled;

    public PodNetworkChaosStatusBuilder() {
        this(true);
    }

    public PodNetworkChaosStatusBuilder(Boolean validationEnabled) {
        this(new PodNetworkChaosStatus(), validationEnabled);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodNetworkChaosStatus(), validationEnabled);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatusFluent<?> fluent,PodNetworkChaosStatus instance) {
        this(fluent, instance, true);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatusFluent<?> fluent,PodNetworkChaosStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withExperiment(instance.getExperiment()); 
        fluent.withFailedMessage(instance.getFailedMessage()); 
        fluent.withPhase(instance.getPhase()); 
        fluent.withReason(instance.getReason()); 
        fluent.withScheduler(instance.getScheduler()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatus instance) {
        this(instance,true);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withExperiment(instance.getExperiment()); 
        this.withFailedMessage(instance.getFailedMessage()); 
        this.withPhase(instance.getPhase()); 
        this.withReason(instance.getReason()); 
        this.withScheduler(instance.getScheduler()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodNetworkChaosStatus build() {
        EditablePodNetworkChaosStatus buildable = new EditablePodNetworkChaosStatus(fluent.getExperiment(),fluent.getFailedMessage(),fluent.getPhase(),fluent.getReason(),fluent.getScheduler());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodNetworkChaosStatusBuilder that = (PodNetworkChaosStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosStatusBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodNetworkChaosStatusBuilder extends PodNetworkChaosStatusFluentImpl<PodNetworkChaosStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<PodNetworkChaosStatus,PodNetworkChaosStatusBuilder> {

    PodNetworkChaosStatusFluent<?> fluent;
    Boolean validationEnabled;

    public PodNetworkChaosStatusBuilder() {
        this(true);
    }

    public PodNetworkChaosStatusBuilder(Boolean validationEnabled) {
        this(new PodNetworkChaosStatus(), validationEnabled);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodNetworkChaosStatus(), validationEnabled);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatusFluent<?> fluent,PodNetworkChaosStatus instance) {
        this(fluent, instance, true);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatusFluent<?> fluent,PodNetworkChaosStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withExperiment(instance.getExperiment()); 
        fluent.withFailedMessage(instance.getFailedMessage()); 
        fluent.withScheduler(instance.getScheduler()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatus instance) {
        this(instance,true);
    }

    public PodNetworkChaosStatusBuilder(PodNetworkChaosStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withExperiment(instance.getExperiment()); 
        this.withFailedMessage(instance.getFailedMessage()); 
        this.withScheduler(instance.getScheduler()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodNetworkChaosStatus build() {
        EditablePodNetworkChaosStatus buildable = new EditablePodNetworkChaosStatus(fluent.getExperiment(),fluent.getFailedMessage(),fluent.getScheduler());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodNetworkChaosStatusBuilder that = (PodNetworkChaosStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
